@@ -65,11 +65,10 @@ def is_mpath_device(devpath, info=None):
 def is_mpath_member(devpath, info=None):
     """ Check if a device is a multipath member (a path), returns boolean. """
     result = False
-    try:
-        util.subp(['multipath', '-c', devpath], capture=True)
+    if not info:
+        info = udev.udevadm_info(devpath)
+    if info.get("DM_MULTIPATH_DEVICE_PATH") == "1":
         result = True
-    except util.ProcessExecutionError:
-        pass
 
     LOG.debug('%s is multipath device member? %s', devpath, result)
     return result
@@ -81,7 +80,7 @@ def is_mpath_partition(devpath, info=None):
     if devpath.startswith('/dev/dm-'):
         if not info:
             info = udev.udevadm_info(devpath)
-        if 'DM_PART' in udev.udevadm_info(devpath):
+        if 'DM_PART' in info and 'DM_MPATH' in info:
             result = True
 
     LOG.debug("%s is multipath device partition? %s", devpath, result)
