@@ -80,7 +80,7 @@ class HirsuteTestIscsiBasic(relbase.hirsute, TestBasicIscsiAbs):
     __test__ = True
 
 
-class GroovyTestIscsiBasic(relbase.groovy, TestBasicIscsiAbs):
+class ImpishTestIscsiBasic(relbase.impish, TestBasicIscsiAbs):
     __test__ = True
 
 
