@@ -31,7 +31,7 @@ class HirsuteTestNetworkIPV6Static(relbase.hirsute, TestNetworkIPV6StaticAbs):
     __test__ = True
 
 
-class GroovyTestNetworkIPV6Static(relbase.groovy, TestNetworkIPV6StaticAbs):
+class ImpishTestNetworkIPV6Static(relbase.impish, TestNetworkIPV6StaticAbs):
     __test__ = True
 
 
