@@ -73,8 +73,18 @@ class BionicTestNvme(relbase.bionic, TestNvmeAbs):
     __test__ = True
 
 
-class GroovyTestNvme(relbase.groovy, TestNvmeAbs):
-    __test__ = True
+class FocalTestNvme(relbase.focal, TestNvmeAbs):
+    __test__ = False
+    # An error occured handling 'nvme_disk2':
+    # OSError - [Errno 16] Device or resource busy: '/dev/mapper/mpatha'
+
+
+class HirsuteTestNvme(relbase.hirsute, TestNvmeAbs):
+    __test__ = False
+
+
+class ImpishTestNvme(relbase.impish, TestNvmeAbs):
+    __test__ = False
 
 
 class TestNvmeBcacheAbs(TestNvmeAbs):
@@ -147,7 +157,7 @@ class HirsuteTestNvmeBcache(relbase.hirsute, TestNvmeBcacheAbs):
     __test__ = True
 
 
-class GroovyTestNvmeBcache(relbase.groovy, TestNvmeBcacheAbs):
+class ImpishTestNvmeBcache(relbase.impish, TestNvmeBcacheAbs):
     __test__ = True
 
 
